@@ -7,6 +7,7 @@
 from sys import exit
 from typing import Union
 
+from platform import system
 from requests import Session
 from requests.cookies import RequestsCookieJar
 from requests.structures import CaseInsensitiveDict
@@ -17,6 +18,7 @@ from selenium.webdriver.chrome.webdriver import WebDriver
 from selenium.webdriver.remote.webdriver import WebDriver as RemoteWebDriver
 from tldextract import extract
 
+from .common import get_pid_from_port, connect_chrome
 from .config import _session_options_to_dict, SessionOptions, DriverOptions, _cookies_to_tuple
 
 
@@ -104,30 +106,27 @@ class Drission(object):
                 self.driver_options.add_argument(f'--proxy-server={self._proxy["http"]}')
 
             driver_path = self.driver_options.driver_path or 'chromedriver'
-            chrome_path = self.driver_options.binary_location or 'chrome.exe'
+            chrome_path = self.driver_options.chrome_path
 
             # -----------若指定debug端口且该端口未在使用中，则先启动浏览器进程-----------
-            if self.driver_options.debugger_address and _check_port(self.driver_options.debugger_address) is False:
-                from subprocess import Popen
-                port = self.driver_options.debugger_address.split(':')[-1]
-
+            if self.driver_options.debugger_address:
                 # 启动浏览器进程，同时返回该进程使用的 chrome.exe 路径
-                chrome_path, self._debugger = _create_chrome(chrome_path, port,
-                                                             self.driver_options.arguments, self._proxy)
+                chrome_path, self._debugger = connect_chrome(self.driver_options)
 
             # -----------创建WebDriver对象-----------
             self._driver = _create_driver(chrome_path, driver_path, self.driver_options)
 
+            # -----------解决接管新版浏览器不能定位到正确的标签页的问题-----------
+            active_tab = self._driver.window_handles[0]
+            if active_tab != self._driver.current_window_handle:
+                self._driver.switch_to.window(active_tab)
+
             # 反反爬设置
             try:
                 self._driver.execute_script('Object.defineProperty(navigator,"webdriver",{get:() => undefined,});')
             except Exception:
                 pass
 
-            # self._driver.execute_cdp_cmd(
-            #     'Page.addScriptToEvaluateOnNewDocument',
-            #     {'source': 'Object.defineProperty(navigator,"webdriver",{get:() => Chrome,});'})
-
         return self._driver
 
     @property
@@ -183,19 +182,8 @@ class Drission(object):
 
     def kill_browser(self) -> None:
         """关闭浏览器进程（如果可以）"""
-        if self.debugger_progress:
-            self.debugger_progress.kill()
-            return
-
         pid = self.get_browser_progress_id()
-        from os import popen
-        from platform import system
-
-        if pid and system().lower() == 'windows' \
-                and popen(f'tasklist | findstr {pid}').read().lower().startswith('chrome.exe'):
-            popen(f'taskkill /pid {pid} /F')
-
-        else:
+        if not _kill_progress(pid):
             self._driver.quit()
 
     def get_browser_progress_id(self) -> Union[str, None]:
@@ -230,7 +218,6 @@ class Drission(object):
         self._show_or_hide_browser(False)
 
     def _show_or_hide_browser(self, hide: bool = True) -> None:
-        from platform import system
         if system().lower() != 'windows':
             raise OSError('该方法只能在Windows系统使用。')
 
@@ -364,6 +351,8 @@ class Drission(object):
     def close_driver(self, kill: bool = False) -> None:
         """关闭driver和浏览器"""
         if self._driver:
+            _kill_progress(port=self._driver.service.port)  # 关闭chromedriver.exe进程
+
             if kill:
                 self.kill_browser()
             else:
@@ -398,75 +387,6 @@ def user_agent_to_session(driver: RemoteWebDriver, session: Session) -> None:
     session.headers.update({"User-Agent": selenium_user_agent})
 
 
-def _check_port(debugger_address: str) -> Union[bool, None]:
-    """检查端口是否被占用                               \n
-    :param debugger_address: 浏览器地址及端口
-    :return: bool
-    """
-    import socket
-
-    ip, port = debugger_address.split(':')
-
-    if ip not in ('127.0.0.1', 'localhost'):
-        return
-
-    s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-
-    try:
-        s.connect((ip, int(port)))
-        s.shutdown(2)
-        return True
-    except socket.error:
-        return False
-    finally:
-        if s:
-            s.close()
-
-
-def _create_chrome(chrome_path: str, port: str, args: list, proxy: dict) -> tuple:
-    """创建 chrome 进程                          \n
-    :param chrome_path: chrome.exe 路径
-    :param port: 进程运行的端口号
-    :param args: chrome 配置参数
-    :return: chrome.exe 路径和进程对象组成的元组
-    """
-    from subprocess import Popen
-
-    # ----------为路径加上双引号，避免路径中的空格产生异常----------
-    args1 = []
-    for arg in args:
-        if arg.startswith(('--user-data-dir', '--disk-cache-dir')):
-            index = arg.find('=') + 1
-            args1.append(f'{arg[:index]}"{arg[index:].strip()}"')
-        else:
-            args1.append(arg)
-
-    args = ' '.join(set(args1))
-
-    if proxy:
-        args = f'{args} --proxy-server={proxy["http"]}'
-
-    # ----------创建浏览器进程----------
-    try:
-        debugger = Popen(f'{chrome_path} --remote-debugging-port={port} {args}', shell=False)
-
-        if chrome_path == 'chrome.exe':
-            from .common import get_exe_path_from_port
-            chrome_path = get_exe_path_from_port(port)
-
-    # 传入的路径找不到，主动在ini文件、注册表、系统变量中找
-    except FileNotFoundError:
-        from DrissionPage.easy_set import _get_chrome_path
-        chrome_path = _get_chrome_path(show_msg=False)
-
-        if not chrome_path:
-            raise FileNotFoundError('无法找到chrome.exe路径，请手动配置。')
-
-        debugger = Popen(f'"{chrome_path}" --remote-debugging-port={port} {args}', shell=False)
-
-    return chrome_path, debugger
-
-
 def _create_driver(chrome_path: str, driver_path: str, options: Options) -> WebDriver:
     """创建 WebDriver 对象                            \n
     :param chrome_path: chrome.exe 路径
@@ -488,7 +408,7 @@ def _create_driver(chrome_path: str, driver_path: str, options: Options) -> WebD
         from .easy_set import get_match_driver
         from DrissionPage.easy_set import _get_chrome_path
 
-        if chrome_path == 'chrome.exe':
+        if chrome_path == 'chrome':
             chrome_path = _get_chrome_path(show_msg=False, from_ini=False)
 
         if chrome_path:
@@ -505,7 +425,7 @@ def _create_driver(chrome_path: str, driver_path: str, options: Options) -> WebD
 
 
 def _get_chrome_hwnds_from_pid(pid) -> list:
-    # 通过PID查询句柄ID
+    """通过PID查询句柄ID"""
     try:
         from win32gui import IsWindow, GetWindowText, EnumWindows
         from win32process import GetWindowThreadProcessId
@@ -522,3 +442,24 @@ def _get_chrome_hwnds_from_pid(pid) -> list:
     hwnds = []
     EnumWindows(callback, hwnds)
     return hwnds
+
+
+def _kill_progress(pid: str = None, port: int = None) -> bool:
+    """关闭浏览器进程                                 \n
+    :param pid: 进程id
+    :param port: 端口号，如没有进程id，从端口号获取
+    :return: 是否成功
+    """
+    from os import popen
+    if system().lower() != 'windows':
+        return False
+
+    pid = pid or get_pid_from_port(port)
+    if not pid:
+        return False
+
+    if popen(f'tasklist | findstr {pid}').read().lower().startswith('chrome.exe'):
+        popen(f'taskkill /pid {pid} /F')
+        return True
+    else:
+        return False
