@@ -30,9 +30,10 @@ class DriverElement(DrissionElement):
         :param ele: 被包装的WebElement元素
         :param page: 元素所在页面
         """
-        super().__init__(ele, page)
+        super().__init__(page)
         self._select = None
         self._scroll = None
+        self._inner_ele = ele
 
     def __repr__(self) -> str:
         attrs = [f"{attr}='{self.attrs[attr]}'" for attr in self.attrs]
@@ -50,6 +51,10 @@ class DriverElement(DrissionElement):
         return self.ele(loc_or_str, timeout)
 
     # -----------------共有属性和方法-------------------
+    @property
+    def inner_ele(self) -> WebElement:
+        return self._inner_ele
+
     @property
     def tag(self) -> str:
         """返回元素类型"""
@@ -147,11 +152,13 @@ class DriverElement(DrissionElement):
     def _ele(self,
              loc_or_str: Union[Tuple[str, str], str],
              timeout: float = None,
-             single: bool = True) -> Union['DriverElement', str, None, List[Union['DriverElement', str]]]:
+             single: bool = True,
+             relative: bool = False) -> Union['DriverElement', str, None, List[Union['DriverElement', str]]]:
         """返回当前元素下级符合条件的子元素、属性或节点文本，默认返回第一个                                      \n
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
         :param timeout: 查找元素超时时间
         :param single: True则返回第一个，False则返回全部
+        :param relative: WebPage用的表示是否相对定位的参数
         :return: DriverElement对象
         """
         return make_driver_ele(self, loc_or_str, single, timeout)
@@ -285,7 +292,7 @@ class DriverElement(DrissionElement):
                index: int = 1,
                filter_loc: Union[tuple, str] = '',
                timeout: float = None) -> Union['DriverElement', str, None]:
-        """返回前面的一个兄弟元素，可用查询语法筛选，可指定返回筛选结果的第几个        \n
+        """返回当前元素前面的一个元素，可指定筛选条件和第几个。查找范围不限兄弟元，而是整个DOM文档        \n
         :param index: 前面第几个查询结果元素
         :param filter_loc: 用于筛选元素的查询语法
         :param timeout: 查找元素的超时时间
@@ -297,7 +304,7 @@ class DriverElement(DrissionElement):
               index: int = 1,
               filter_loc: Union[tuple, str] = '',
               timeout: float = None) -> Union['DriverElement', str, None]:
-        """返回后面的一个兄弟元素，可用查询语法筛选，可指定返回筛选结果的第几个        \n
+        """返回当前元素后面的一个元素，可指定筛选条件和第几个。查找范围不限兄弟元，而是整个DOM文档        \n
         :param index: 后面第几个查询结果元素
         :param filter_loc: 用于筛选元素的查询语法
         :param timeout: 查找元素的超时时间
@@ -328,7 +335,7 @@ class DriverElement(DrissionElement):
     def befores(self,
                 filter_loc: Union[tuple, str] = '',
                 timeout: float = None) -> List[Union['DriverElement', str]]:
-        """返回后面全部兄弟元素或节点组成的列表，可用查询语法筛选        \n
+        """返回当前元素后面符合条件的全部兄弟元素或节点组成的列表，可用查询语法筛选。查找范围不限兄弟元，而是整个DOM文档        \n
         :param filter_loc: 用于筛选元素的查询语法
         :param timeout: 查找元素的超时时间
         :return: 本元素前面的元素或节点组成的列表
@@ -338,7 +345,7 @@ class DriverElement(DrissionElement):
     def afters(self,
                filter_loc: Union[tuple, str] = '',
                timeout: float = None) -> List[Union['DriverElement', str]]:
-        """返回前面全部兄弟元素或节点组成的列表，可用查询语法筛选        \n
+        """返回当前元素前面符合条件的全部兄弟元素或节点组成的列表，可用查询语法筛选。查找范围不限兄弟元，而是整个DOM文档        \n
         :param filter_loc: 用于筛选元素的查询语法
         :param timeout: 查找元素的超时时间
         :return: 本元素后面的元素或节点组成的列表
@@ -537,6 +544,8 @@ class DriverElement(DrissionElement):
         :return: bool
         """
         if not insure or self.tag != 'input' or self.prop('type') != 'text':  # 普通输入
+            if not isinstance(vals, (str, tuple)):
+                vals = str(vals)
             if clear:
                 self.inner_ele.clear()
 
@@ -545,7 +554,7 @@ class DriverElement(DrissionElement):
 
         else:  # 确保输入正确
             if not isinstance(vals, str):
-                raise TypeError('insure参数生效时vals只能接收str数据。')
+                vals = str(vals)
             enter = '\n' if vals.endswith('\n') else None
             full_txt = vals if clear else f'{self.attr("value")}{vals}'
             full_txt = full_txt.rstrip('\n')
@@ -623,25 +632,31 @@ class DriverElement(DrissionElement):
         except Exception:
             return False
 
-    def screenshot(self, path: str, filename: str = None) -> str:
-        """对元素进行截图                                          \n
+    def screenshot(self, path: str = None, filename: str = None, as_bytes: bool = False) -> Union[str, bytes]:
+        """对元素进行截图                                              \n
         :param path: 保存路径
         :param filename: 图片文件名，不传入时以元素tag name命名
-        :return: 图片完整路径
+        :param as_bytes: 是否已字节形式返回图片，为True时上面两个参数失效
+        :return: 图片完整路径或字节文本
         """
-        name = filename or self.tag
-        path = Path(path).absolute()
-        path.mkdir(parents=True, exist_ok=True)
-        if not name.lower().endswith('.png'):
-            name = f'{name}.png'
-
         # 等待元素加载完成
         if self.tag == 'img':
             js = ('return arguments[0].complete && typeof arguments[0].naturalWidth != "undefined" '
-                  '&& arguments[0].naturalWidth > 0')
-            while not self.run_script(js):
+                  '&& arguments[0].naturalWidth > 0 && typeof arguments[0].naturalHeight != "undefined" '
+                  '&& arguments[0].naturalHeight > 0')
+            t1 = perf_counter()
+            while not self.run_script(js) and perf_counter() - t1 < self.page.timeout:
                 pass
 
+        if as_bytes:
+            return self.inner_ele.screenshot_as_png
+
+        name = filename or self.tag
+        path = Path(path or '.').absolute()
+        path.mkdir(parents=True, exist_ok=True)
+        if not name.lower().endswith('.png'):
+            name = f'{name}.png'
+
         img_path = str(get_usable_path(f'{path}{sep}{name}'))
         self.inner_ele.screenshot(img_path)
 
@@ -764,10 +779,7 @@ class DriverElement(DrissionElement):
         :param loc: 筛选条件，可用selenium的(By, str)，也可用本库定位语法
         :return: DriverElement对象
         """
-        try:
-            from selenium.webdriver.support.relative_locator import RelativeBy
-        except ImportError:
-            raise ImportError('该方法只支持selenium4及以上版本。')
+        from selenium.webdriver.support.relative_locator import RelativeBy
 
         if isinstance(loc, str):
             loc = str_to_loc(loc)
