@@ -6,13 +6,13 @@
 """
 from re import match, DOTALL
 from typing import Union, List, Tuple
-from urllib.parse import urlparse, urljoin, urlunparse
 
 from lxml.etree import tostring
 from lxml.html import HtmlElement, fromstring
+# from lxml.etree import Element as HtmlElement, fromstring
 
 from .base import DrissionElement, BasePage, BaseElement
-from .common import get_ele_txt, get_loc
+from .common import get_ele_txt, get_loc, make_absolute_link
 
 
 class SessionElement(DrissionElement):
@@ -23,7 +23,12 @@ class SessionElement(DrissionElement):
         :param ele: 被包装的HtmlElement元素
         :param page: 元素所在页面对象，如果是从 html 文本生成的元素，则为 None
         """
-        super().__init__(ele, page)
+        super().__init__(page)
+        self._inner_ele = ele
+
+    @property
+    def inner_ele(self) -> HtmlElement:
+        return self._inner_ele
 
     def __repr__(self) -> str:
         attrs = [f"{attr}='{self.attrs[attr]}'" for attr in self.attrs]
@@ -180,10 +185,10 @@ class SessionElement(DrissionElement):
                 return link
 
             else:  # 其它情况直接返回绝对url
-                return self._make_absolute(link)
+                return make_absolute_link(link, self.page)
 
         elif attr == 'src':
-            return self._make_absolute(self.inner_ele.get('src'))
+            return make_absolute_link(self.inner_ele.get('src'), self.page)
 
         elif attr == 'text':
             return self.text
@@ -239,11 +244,13 @@ class SessionElement(DrissionElement):
     def _ele(self,
              loc_or_str: Union[Tuple[str, str], str],
              timeout=None,
-             single: bool = True) -> Union['SessionElement', str, None, List[Union['SessionElement', str]]]:
+             single: bool = True,
+             relative: bool = False) -> Union['SessionElement', str, None, List[Union['SessionElement', str]]]:
         """返回当前元素下级符合条件的子元素、属性或节点文本，默认返回第一个           \n
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
         :param timeout: 不起实际作用，用于和父类对应
         :param single: True则返回第一个，False则返回全部
+        :param relative: WebPage用的表示是否相对定位的参数
         :return: SessionElement对象
         """
         return make_session_ele(self, loc_or_str, single)
@@ -268,30 +275,6 @@ class SessionElement(DrissionElement):
 
         return f':root{path_str[1:]}' if mode == 'css' else path_str
 
-    # ----------------session独有方法-----------------------
-    def _make_absolute(self, link) -> str:
-        """获取绝对url
-        :param link: 超链接
-        :return: 绝对链接
-        """
-        if not link:
-            return link
-
-        parsed = urlparse(link)._asdict()
-
-        # 是相对路径，与页面url拼接并返回
-        if not parsed['netloc']:
-            return urljoin(self.page.url, link) if self.page else link
-
-        # 是绝对路径但缺少协议，从页面url获取协议并修复
-        if not parsed['scheme'] and self.page:
-            parsed['scheme'] = urlparse(self.page.url).scheme
-            parsed = tuple(v for v in parsed.values())
-            return urlunparse(parsed)
-
-        # 绝对路径且不缺协议，直接返回
-        return link
-
 
 def make_session_ele(html_or_ele: Union[str, BaseElement, BasePage],
                      loc: Union[str, Tuple[str, str]] = None,
